---
title: '[공지] 포트원 문자 오발송 안내 공지'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-03-06T15:00:00.000Z
---

현재 포트원 고객센터에서 문자가 오발송 되어 공지 안내드립니다.

당사 유선 연락처는 맞으나 내부 고객공지를 위한 시스템 구축 준비과정에서 문자가 오발송 된 건으로 현재 조치완료 되었습니다.

불편드려 죄송합니다.

참고로 당사 결제시스템에는 영향이 없으니 참고부탁드립니다.
